.if hlp
.helpb format__of__commands
.s
.else hlp
.CHAPTER RUNOFF COMMANDS 
.INDEX RUNOFF COMMANDS 
.INDEX COMMAND FORMAT 
.endif hlp
.ifnot small
This chapter contains a list of all RUNOFF commands. You probably will not
want to read all of this chapter, as it is intended to be used as a reference
manual.  If you have never used RNO before then you should thoroughly read the
chapter "Introduction to the commands". 
.endif small
.f.p
All commands begin with a period(.). 
.ifnot small
Any line in the source file beginning
with a period is assumed to contain one or more commands.  If the text after
the period is not recognized as a command an error message is typed. 
.endif small
Most commands have arguments following them. An argument is a number or line
of text that controls how the command works. Multiple arguments may be
separated by spaces, tabs, or commas. If the arguments are separated by
commas, any number of tabs or spaces may appear before or after the comma.
When you look at the description of a command certain conventions are used to
describe the arguments. If the argument is enclosed inside square brackets []
it may be omitted. 
.ifnot small
.if hlp
.if rsx .i5;FURTHER HELP: numbers literals multiple abbreviations
.endif rsx
.endif hlp
.helpc numbers
.p
.endif small
Most arguments are numbers.  If the number is
preceeded by a minus sign (-) then it may be entered as a negative value.  If
it is preceeded by +- then it may be a relative argument.  A relative argument
changes the old value by + or - the value specified. 
.ifnot small
Many arguments have limits.  For example page numbers must be in the range of
1 to 3999.  Each command documents the limits on its arguments.
.p
For example you enter the
left margin as 5 then it will be set to exactly 5.  If you enter it as +5 the
new left margin is equal to the old one plus 5 more.  If you enter it as -5
then the new margin is 5 less than the old margin. 
.helpc literals
.p
.endif small
Some commands have literal arguments.  A literal is a line of text
enclosed in either apostrophes (') or quotes (").
If the quotes are used, and you wish to use a quote inside the string
you must use it twice.  
.ifnot small
Similarly if you enclose the text in apostrophes
a double apostrophe will be interpreted as a single apostrophe.
For example legal literals are:
.i5;'"legal" literal'
.i5;"""legal"" literal"
.br;Either of these will appear as: "legal" literal
.br;The following are not legal literals:
.i5;'illegal literal"
.i5;'illegal' literal'
.i5;''illegal literal'
.br;Tabs enclosed inside a literal are treated as single spaces.
A literal is also terminated by the end of a line.  This termination may
not be supported in future versions. 
.helpc multiple
.p 
.endif small
More than one command may be entered on a single line.  The commands may be
optionally separated by a semicolon ";", spaces, or tabs. If the semicolon is
used as a separator the next command must immediately follow with no
intervening spaces or tabs. Commands which are followed by text must be the
last command on a line, and may not have other commands after them on the same
line. 
.ifnot small
These include: 
.keep tabs
.ts +2,+17,+17,+17,+17,+17,+17 .nj.dhy
	_.APPENDIX	_.CHAPTER	_.FIRST#TITLE	_.HEADER#LEVEL
	_.INDEX	_.LIST#ELEMENT	_.REQUIRE	_.SEND
	_.SUBTITLE	_.TITLE
.j.ehy
For example the following line is a legal set of commands all on 1 line: 
.s.i5;_.TT 10 .Fill;.EH _.Title GONE WITH THE WIND 
.p; Commands may have text following them provided the text is separated 
from the command by a semicolon (;).  For example the following line will 
produce a centered title. 
.i5; _.C;THIS IS A TITLE 
.br; The semicolon is essentially a separator which indicates that the rest 
of the line is to be treated just as if a new line had begun. 
.helpc abbreviations
.p
Many commands may be abbreviated. Standard abbreviations are given below each
command. Many other abbreviations will work, but only the standard ones are
guaranteed to work. Multi-word commands may appear without spaces. For example
the following forms of the _.PAGE SIZE command are all legal: 
.text
.nf.lm+5
_.PAGE  SIZE 20,20, 4, 1, 1
_.PAGE SIZE 20 , 20
_.PAGESIZE 20 20
_.PS ,,1,2
_.ps , , 1 2
_.PAG SIZ 25
.lm.f
.end text
.p
Many commands have defaults.  In other words if you do not specify the
arguments you get the default ones.
.helpc user
.p
It is possible to define your own commands.  The program will search for 
either a standard command or a user defined command.  If you wish to specify
one or the other preface the user command with an underscore "__" and
a standard command with a dollar sign "_$".  For example you might have
a user command called FIGURE, but there is also a standard command of the
same name.  To use your command the command is:
.i5;_.__FIGURE
.br;While the standard command is:
.i5;_._$FIGURE
.endif small
